import { ClientConnection } from 'message-event-channel';
export interface ContentItemLink {
    _meta: {
        schema: string;
    };
    id: string;
    contentType: string;
}
export interface ContentLinkOptions {
    max?: number | null;
}
export declare class ContentLink {
    private connection;
    /**
     * Content Link - Use to open the content browser.
     *
     * @param connection message-event-channel connection
     */
    constructor(connection: ClientConnection);
    /**
     * This method will trigger a content browser. It returns a promise that will resolve to the chosen Content References.
     *
     * @param contentTypeIds list of Content Type Ids to filter the Content Browser by.
     * @param options.max Max amount of selected contnet links
     *
     * ### Example
     * ```typescript
     * const enums = sdk.field.schema.allOf[1].properties.contentType.enum;
     * const contentLink = await sdk.contentLink.getMultiple(enums);
     *
     * console.log(contentLink);
     * ```
     */
    getMultiple(contentTypeIds: Array<string>, options?: ContentLinkOptions): Promise<ContentItemLink[]>;
    /**
     * This method will trigger a content browser. It returns a promise that will resolve to the chosen Content Link.
     *
     * @param contentTypeIds list of Content Type Ids to filter the Content Browser by.
     *
     * ### Example
     * ```typescript
     * const enums = sdk.field.schema.allOf[1].properties.contentType.enum;
     * const contentLink = await sdk.contentLink.get(enums);
     *
     * console.log(contentLink);
     * ```
     */
    get(contentTypeIds: Array<string>): Promise<ContentItemLink>;
    fetchLinks(contentTypeIds: Array<string>, max?: number | null): Promise<any>;
}
